@@ -2,13 +2,14 @@ osmTiles = function(name, xyz, suffix) {
   result = c(
     osm = "http://tile.openstreetmap.org",
     'osm-admin' = 'http://korona.geog.uni-heidelberg.de/tiles/adminb',
-    'osm-roads-grey' = 'http://korona.geog.uni-heidelberg.de/tiles/roadsg',
+    'osm-roads-grey' = 'http://korona.geog.uni-heidelberg.de/tiles/roadsg/',
     'osm-roads' = 'http://korona.geog.uni-heidelberg.de/tiles/roads',
-    'osm-semitransparent' = 'http://korona.geog.uni-heidelberg.de/tiles/hybrid',
-    "osm-no-labels"="http://a.tiles.wmflabs.org/osm",
-    "osm-de"="http://c.tile.openstreetmap.de/tiles/osmde",
+    'osm-semitransparent' = 'http://korona.geog.uni-heidelberg.de/tiles/hybrid/',
+    "osm-no-labels"="http://c.tiles.wmflabs.org/osm-no-labels/",
+    "osm-de"="http://c.tile.openstreetmap.de/tiles/osmde/",
+    "osm-ru" = "http://a.tiles.wmflabs.org/osm-multilingual/ru,_/",
     "osm-transport"="http://tile2.opencyclemap.org/transport/",
-    "bw-mapnik"="http://tiles.wmflabs.org/bw-mapnik",
+    "bw-mapnik"="http://b.tiles.wmflabs.org/bw-mapnik2/",
 #			mapquest="http://otile1.mqcdn.com/tiles/1.0.0/osm/",
 #			"mapquest-sat"="http://otile1.mqcdn.com/tiles/1.0.0/sat",
 #      "mapquest-labels"='http://otile3.mqcdn.com/tiles/1.0.0/hyb/',
